@@ -23,7 +23,7 @@
 #' @keywords internal
 util_study_var2factor <- function(resp_vars = NULL, study_data,
                                   meta_data = "item_level", # TODO: make a prep, see util_assign_levlabs, make it work also for VALUE_LABELS, not only for missing codes, optionally. Default should be FALSE or all existing calls need to be edited to turn off this feature. Maybe, the prep is just a copy of the util with modified defaults, as in  progress <- other_function; formals(progress)$is_rstudio <- force(is_rstudio)
-                                  label_col = LABEL,
+                                  label_col = LABEL,        # TODO: This is now available in prep_prepare_dataframes(.apply_factor_metadata = ) or prep_prepare_dataframes(.apply_factor_metadata_inadm = )
                                   assume_consistent_codes = TRUE,
                                   have_cause_label_df = FALSE,
                                   code_name = c(JUMP_LIST, MISSING_LIST),
@@ -33,7 +33,9 @@ util_study_var2factor <- function(resp_vars = NULL, study_data,
   util_expect_scalar(code_name, allow_more_than_one = TRUE, allow_null = TRUE,
                      check_type = is.character)
   util_expect_data_frame(meta_data, code_name)
+  .meta_data <- meta_data # FIXME: Save metadata here, but we should not rely on VALUE_LABELS, any more
   prep_prepare_dataframes(.replace_missings = FALSE)
+  meta_data <- .meta_data
   util_correct_variable_use2(resp_vars,
                              allow_more_than_one = TRUE,
                              allow_na = TRUE,
