@@ -1,26 +1,15 @@
 test_that("acc_varcomp works without label_col", {
   skip_on_cran()
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
-  expect_warning(
-    expect_error({
-      res1 <-
-        acc_varcomp(resp_vars = "v00014", study_data = study_data,
-                    meta_data = meta_data)
-    },
-    regexp =
-      paste(".*acc_varcomp expects one group_var per resp_var.",
-            "Here, it has been called with 1 resp_vars but 0 group_vars"),
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
+  expect_error({
+    res1 <-
+      acc_varcomp(resp_vars = "v00014", study_data = study_data,
+                  meta_data = meta_data)
+  }, regexp =
+    paste("Argument group_vars is NULL"),
     perl = TRUE
-    ),
-    regexp =
-      sprintf(
-        "(%s)",
-        paste("Missing argument .+group_vars.+",
-              "without default value. Setting to NULL.")
-      ),
-    perl = TRUE,
-    all = TRUE
   )
 
   expect_error(
@@ -31,26 +20,16 @@ test_that("acc_varcomp works without label_col", {
     regexp =
       sprintf(
         "(%s)",
-        paste("Need exactly one element in argument group_vars,",
-              "got 2: .DEV_NO_0, USR_BP_0.")
+  paste("Need exactly one element in argument resp_vars, got 2: .CRP_0, SBP_0.")
       ),
     perl = TRUE
   )
 
-  suppressMessages(expect_message(
+  suppressMessages(
     res1 <-
-      acc_varcomp(resp_vars = c("DBP_0", "SBP_0"), study_data = study_data,
+      acc_varcomp(resp_vars = c("DBP_0"), study_data = study_data,
                   meta_data = meta_data, group_vars = c("USR_BP_0"),
-                  label_col = LABEL),
-    regexp =
-      sprintf(
-        "(%s)",
-        paste("Levels .+USR_559.+ were excluded",
-              "due to less than 30 observations.")
-      ),
-    perl = TRUE,
-    all = FALSE
-  ))
+                  label_col = LABEL))
 
   expect_true(all(
     c("SummaryTable",
@@ -61,41 +40,28 @@ test_that("acc_varcomp works without label_col", {
   expect_lt(
     suppressWarnings(abs(sum(as.numeric(
       as.matrix(res1$SummaryTable)),
-      na.rm = TRUE) - 1638.564)), 0.1
+      na.rm = TRUE) - 784.112)), 0.1
   )
 
-  expect_equal(res1$ScalarValue_max_icc, 0.111)
-  expect_equal(res1$ScalarValue_argmax_icc, "DBP_0")
+  expect_true(res1$ScalarValue_max_icc == 0.112)
+  expect_true(res1$ScalarValue_argmax_icc == "DBP_0")
 
 })
 
 test_that("acc_varcomp works with label_col", {
   skip_on_cran()
-
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
-  expect_warning(
-    expect_error({
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
+  expect_error({
       res1 <-
         acc_varcomp(resp_vars = "SBP_0", study_data = study_data,
                     label_col = LABEL,
                     meta_data = meta_data)
     },
-    regexp = paste(".*acc_varcomp expects one group_var per resp_var. Here,",
-                   "it has been called with 1 resp_vars but 0 group_vars"),
-    perl = TRUE
-    ),
-    regexp =
-      sprintf(
-        "(%s)",
-        paste("Missing argument .+group_vars.+",
-              "without default value. Setting to NULL.")
-      ),
-    perl = TRUE,
-    all = TRUE
+    regexp = paste("Argument group_vars is NULL")
   )
 
-
   res1 <-
     acc_varcomp(resp_vars = "v00014", study_data = study_data,
                 meta_data = meta_data, group_vars = "v00016")
@@ -120,28 +86,33 @@ test_that("acc_varcomp works with label_col", {
 
 test_that("acc_varcomp works illegal min_obs_in_subgroup/min_subgroups", {
   skip_on_cran()
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
-  suppressMessages(expect_message(
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
+  suppressMessages(expect_error(
     res1 <-
-      acc_varcomp(resp_vars = c("DBP_0", "SBP_0"), study_data = study_data,
+      acc_varcomp(resp_vars = c("DBP_0"), study_data = study_data,
                   meta_data = meta_data, group_vars = c("USR_BP_0"),
                   label_col = LABEL, min_obs_in_subgroup = "k",
                   min_subgroups = "x"),
     regexp =
       sprintf(
         "(%s|%s|%s)",
-        paste("Could not convert min_obs_in_subgroup .+k.+ to a",
-              "number. Set to standard value."),
+        paste("min_obs_in_subgroup needs to be integer > 0"),
         paste("Could not convert min_subgroups .+x.+ to a number.",
               "Set to standard value."),
         paste("Levels .+USR_559.+ were excluded",
-              "due to less than 30 observations.")
-      ),
-    perl = TRUE,
-    all = FALSE
+              "due to fewer than 30 observations.")
+      )
   ))
 
+  suppressMessages(
+    res1 <-
+      acc_varcomp(resp_vars = c("DBP_0"), study_data = study_data,
+                  meta_data = meta_data, group_vars = c("USR_BP_0"),
+                  label_col = LABEL)
+  )
+
   expect_true(all(
     c("SummaryTable",
       "ScalarValue_max_icc",
@@ -151,19 +122,19 @@ test_that("acc_varcomp works illegal min_obs_in_subgroup/min_subgroups", {
   expect_lt(
     suppressWarnings(abs(sum(as.numeric(
       as.matrix(res1$SummaryTable)),
-      na.rm = TRUE) - 1638.564)), 0.1
+      na.rm = TRUE) - 784.112)), 0.1
   )
 
-  expect_equal(res1$ScalarValue_max_icc, 0.111)
-  expect_equal(res1$ScalarValue_argmax_icc, "DBP_0")
+  expect_true(res1$ScalarValue_max_icc == 0.112)
+  expect_true(res1$ScalarValue_argmax_icc == "DBP_0")
 
 })
 
 test_that("acc_varcomp works without resp_vars", {
   skip_on_cran()
-
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
 
   expect_error(
     res1 <-
@@ -171,14 +142,14 @@ test_that("acc_varcomp works without resp_vars", {
                   meta_data = meta_data,
                   group_vars = c("v00016", "v00012")),
     regexp =
-      paste("Need exactly one element in argument group_vars,",
-            "got 2: .v00016, v00012.")
+      paste("Argument resp_vars is NULL")
 
   )
 
   res1 <-
     suppressMessages(acc_varcomp(study_data = study_data,
                 meta_data = meta_data,
+                resp_vars = "v00004",
                 group_vars = "v00016"))
 
   expect_true(all(
@@ -190,22 +161,22 @@ test_that("acc_varcomp works without resp_vars", {
   expect_lt(
     suppressWarnings(abs(sum(as.numeric(
       as.matrix(res1$SummaryTable)),
-      na.rm = TRUE) - 73930.06)), 0.1
+      na.rm = TRUE) - 1932.009)), 0.1
   )
 
-  expect_equal(res1$ScalarValue_max_icc, 0.021)
-  expect_equal(res1$ScalarValue_argmax_icc, "v00014")
+  expect_equal(res1$ScalarValue_max_icc, 0.008)
+  expect_equal(res1$ScalarValue_argmax_icc, "v00004")
 
 
 })
 
 test_that("acc_varcomp stops on too few subgroups", {
   skip_on_cran()
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
 
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
-
-  expect_message(
+  expect_error(
     res1 <-
       acc_varcomp(resp_vars = "v00014",
                   study_data = study_data,
@@ -216,9 +187,9 @@ test_that("acc_varcomp stops on too few subgroups", {
 
   )
 
-  expect_length(res1$ScalarValue_argmax_icc, 0)
-  expect_equal(res1$ScalarValue_max_icc, -Inf)
-  expect_equal(nrow(res1$SummaryTable), 0)
-  expect_equal(ncol(res1$SummaryTable), 11)
+  # expect_length(res1$ScalarValue_argmax_icc, 0)
+  # expect_equal(res1$ScalarValue_max_icc, -Inf)
+  # expect_equal(nrow(res1$SummaryTable), 0)
+  # expect_equal(ncol(res1$SummaryTable), 11)
 
 })
