@@ -1,8 +1,10 @@
 test_that("com_unit_missingness works", {
   skip_on_cran()
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
-  r <- com_unit_missingness(study_data, meta_data, label_col = LABEL,
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
+  r <- com_unit_missingness(study_data, item_level = meta_data,
+                            label_col = LABEL,
                        id_vars = "PSEUDO_ID", strata_vars = "CENTER_0")
   expect_equal(
     length(intersect(
