@@ -12,12 +12,13 @@ test_that("print.dataquieR_resultset2 works", {
 
 test_that("class ReportSummaryTable", {
   skip_on_cran()
-  meta_data <- prep_get_data_frame("meta_data")
-  study_data <- prep_get_data_frame("study_data")
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
   sd1 <- study_data
   md1 <- meta_data
   code_labels <- prep_get_data_frame(
-    "meta_data_v2|missing_table")
+    "https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data_v2.xlsx|missing_table")
 
   md1 <- prep_add_cause_label_df(md1, code_labels)
 
@@ -143,7 +144,7 @@ test_that("class ReportSummaryTable", {
   fkt2(item_miss$ReportSummaryTable, size_min = 80000,
        size_max = 200000)
   fkt2(apm$ReportSummaryTable, size_min = 50000,
-       size_max = 100000)
+       size_max = 200000)
 
   g1 <- R.devices::suppressGraphics(print(apm$ReportSummaryTable,
                                           dt = FALSE))
@@ -151,16 +152,16 @@ test_that("class ReportSummaryTable", {
                                           dt = FALSE))
   g3 <- R.devices::suppressGraphics(print(item_missa$ReportSummaryTable,
                                           dt = FALSE))
-  g4 <- expect_warning(R.devices::suppressGraphics(print(item_miss_emtpy$ReportSummaryTable,
+  expect_warning(R.devices::suppressGraphics(g4 <- print(item_miss_emtpy$ReportSummaryTable,
                                           dt = FALSE)), regexp = "Empty result")
 
   skip_on_cran()
   skip_if_not_installed("vdiffr")
   # TODO: skip_if_not(capabilities()["long.double"])
-  vdiffr::expect_doppelganger("app-ex-repsumtab", g1)
-  vdiffr::expect_doppelganger("im-ex1-repsumtab", g2)
-  vdiffr::expect_doppelganger("im-ex2-repsumtab", g3)
-  expect_warning(vdiffr::expect_doppelganger("im-empty-repsumtab", g4),
+  expect_doppelganger2("app-ex-repsumtab", g1)
+  expect_doppelganger2("im-ex1-repsumtab", g2)
+  expect_doppelganger2("im-ex2-repsumtab", g3)
+  expect_warning(expect_doppelganger2("im-empty-repsumtab", g4),
     regexp = "Empty result")
 
 })
@@ -207,3 +208,66 @@ test_that("print.interval works", {
     fixed = TRUE
   )
 })
+
+test_that("print.ReportSummaryTable works when called within the pipeline with duplicated labels for the plot, which are not the primary labels for the report", {
+  skip_on_cran() # slow test
+  skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
+  meta_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/meta_data.RData")
+  study_data <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/study_data.RData")
+  md0 <- meta_data
+  md0$STUDY_SEGMENT <- NULL
+  md0$LABEL[26:27] <- "EDUCATION"
+  dq <- dq_report2(study_data = study_data, item_level = md0, cores = NULL,
+                   label_col = "LONG_LABEL",
+                   filter_indicator_functions = "com_item_miss")
+  # check that the VAR_NAMES attribute exists and is correct
+  exp_vn <- prep_map_labels(x = c("EDUCATION_0", "EDUCATION_1"),
+                            item_level = md0,
+                            to = VAR_NAMES, from = LONG_LABEL)
+  expect_equal(
+    attr(dq$com_item_missingness.EDUCATION_0$ReportSummaryTable, "VAR_NAMES"),
+    exp_vn[1]
+  )
+  # class(dq$com_item_missingness.EDUCATION_0$ReportSummaryTable) # is a ReportSummaryTable
+  # class(dq["EDUCATION_0", "com_item_missingness", "ReportSummaryTable"]) # is a dataquieR_result
+  # class(dq["EDUCATION_0", "com_item_missingness", "ReportSummaryTable"][[1]]) # is a ReportSummaryTable
+  expect_equal(
+    attr(dq["EDUCATION_0", "com_item_missingness", "ReportSummaryTable"][[1]], "VAR_NAMES"),
+    exp_vn[1]
+  )
+  expect_equal(
+    attr(dq[c("EDUCATION_0", "EDUCATION_1"), "com_item_missingness", "ReportSummaryTable"][[1]], "VAR_NAMES"),
+    exp_vn
+  )
+  # check that the ReportSummaryTable can be printed
+  expect_false(
+    inherits(try(print(dq["EDUCATION_0", "com_item_missingness", "ReportSummaryTable"])), "try-error")
+  )
+  expect_false(
+    inherits(try(dq[, "com_item_missingness", "ReportSummaryTable"]), "try-error")
+  )
+  expect_false(
+    inherits(try(print(dq[, "com_item_missingness", "ReportSummaryTable"])), "try-error")
+  )
+  dq_rst <- dq[c("EDUCATION_0", "EDUCATION_1"), "com_item_missingness", "ReportSummaryTable"]
+  expect_false(
+    inherits(try(print(dq_rst)), "try-error")
+  )
+  expect_false(
+    inherits(try(print(dq_rst$ReportSummaryTable)), "try-error")
+  )
+  expect_false(
+    inherits(try(print(dq_rst[[1]])), "try-error")
+  )
+  # check that the expected axis labels appear in the figure
+  exp_lab <- exp_vn
+  names(exp_lab) <- rep("EDUCATION", 2)
+  exp_lab <- paste(names(exp_lab), paste0("(", exp_lab, ")"))
+  dq_rst_plot <- ggplot_build(print(dq_rst$ReportSummaryTable))
+  expect_true(
+    identical(dq_rst_plot$layout$panel_params[[1]]$x$get_labels(),
+      exp_lab) ||
+    identical(dq_rst_plot$layout$panel_params[[1]]$y$get_labels(),
+      exp_lab)
+  )
+})
